==> ep-framework-gath-1.0.1-b66056.tar: src/Form/Element/MotorcycleSelect.php <==
<?php
namespace Ep\Gath\Form\Element;

use Ep\Gath\Gath;
use Zend\Form\Element\Select;

/**
 * Class MotorcycleSelect
 *
 * @package Gath\Moto\Form\Element
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/gath-moto
 */
class MotorcycleSelect extends Select
{
    /** @var Gath */
    private $gath;
    /** @var int */
    private $modelId;
    /** @var bool */
    protected $disableInArrayValidator = true;
    /** @var string */
    protected $emptyOption = 'Odaberite godinu';
    /** @var array */
    protected $valueOptions;

    /**
     * @param Gath $gath
     */
    public function setGath(Gath $gath): void
    {
        $this->gath = $gath;
    }

    /**
     * @return int
     */
    public function getModelId(): int
    {
        return $this->modelId;
    }

    /**
     * @param int $modelId
     */
    public function setModelId(int $modelId): void
    {
        if ($this->modelId !== $modelId) {
            $this->valueOptions = null;
        }

        $this->modelId = $modelId;
    }

    public function getAttribute($key)
    {
        return 'disabled' === $key ? null === $this->modelId : parent::getAttribute($key);
    }

    public function getAttributes()
    {
        $attributes = parent::getAttributes();

        if (null === $this->modelId) {
            $attributes['disabled'] = true;
        }

        return $attributes;
    }

    /**
     * @return array
     */
    public function getValueOptions()
    {
        if (null === $this->valueOptions) {
            $options = [];

            if (null !== $this->modelId) {
                $motorcycles = $this->gath->getMotorcyclesByModel($this->modelId);

                foreach ($motorcycles['Results'] as $motorcycle) {
                    $options[$motorcycle['MotoId']] = $motorcycle['Year'];
                }
            }

            $this->setValueOptions($options);
        }

        return parent::getValueOptions();
    }
}

==> ep-framework-gath-2.1.59-86a262.tar: src/Form/Element/MotorcycleSelect.php <==
<?php
namespace Ep\Gath\Form\Element;

use Ep\Gath\Gath;
use Laminas\Form\Element\Select;

/**
 * Class MotorcycleSelect
 *
 * @package Gath\Moto\Form\Element
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/gath-moto
 */
class MotorcycleSelect extends Select
{
    /** @var Gath */
    private $gath;
    /** @var int */
    private $modelId;
    /** @var bool */
    protected $disableInArrayValidator = true;
    /** @var string */
    protected $emptyOption = 'Odaberite godinu';
    /** @var array */
    protected $valueOptions;

    /**
     * @param Gath $gath
     */
    public function setGath(Gath $gath): void
    {
        $this->gath = $gath;
    }

    /**
     * @return int
     */
    public function getModelId(): int
    {
        return $this->modelId;
    }

    /**
     * @param int $modelId
     */
    public function setModelId(int $modelId): void
    {
        if ($this->modelId !== $modelId) {
            $this->valueOptions = null;
        }

        $this->modelId = $modelId;
    }

    public function getAttribute($key)
    {
        return 'disabled' === $key ? null === $this->modelId : parent::getAttribute($key);
    }

    public function getAttributes(): array
    {
        $attributes = parent::getAttributes();

        if (null === $this->modelId) {
            $attributes['disabled'] = true;
        }

        return $attributes;
    }

    /**
     * @return array
     */
    public function getValueOptions(): array
    {
        if (null === $this->valueOptions) {
            $options = [];

            if (null !== $this->modelId) {
                $motorcycles = $this->gath->getMotorcyclesByModel($this->modelId);

                foreach ($motorcycles['Results'] as $motorcycle) {
                    $options[$motorcycle['MotoId']] = $motorcycle['Year'];
                }
            }

            $this->setValueOptions($options);
        }

        return parent::getValueOptions();
    }
}
